@@ -16,10 +16,10 @@ OUT_LIST = os.path.join(HERE, "out_list.json")
 
 
 class IoTester(unittest.TestCase):
-    def test_env(self):  # pylint: disable=no-self-use
+    def test_env(self):  # pylint: disable
         pprint(dict(os.environ))
 
-    def test_cmd(self):  # pylint: disable=no-self-use
+    def test_cmd(self):  # pylint: disable
         subprocess.check_call(
             "vidcrawler --help",
             shell=True,
@@ -27,7 +27,7 @@ class IoTester(unittest.TestCase):
             stderr=subprocess.DEVNULL,
         )
 
-    def test_process_test(self):  # pylint: disable=no-self-use
+    def test_process_test(self):  # pylint: disable
         subprocess.check_call(
             f'vidcrawler --input_crawl_json "{FETCH_LIST}" --output_json "{OUT_LIST}"',
             shell=True,
